# TDBRecord

TDBRecord is a simple tool to record your streaming.

[Discord](https://discord.gg/s8bnKD8) 
[PyPi](https://pypi.org/project/TDBRecord/) 
[GitHub](https://github.com/TDBRecord/TDBRecord/)

## Supported streaming services
* Twitch
* AfreecaTV
* YouTube Live

## Requirements
* Python 3.6+
* [ffmpeg](https://ffmpeg.org/)

## Usage
```
$ tdbrec config # Create config file
$ tdbrec start # Start recording
$ tdbrec record <user> <platform> # Record specific user
           --download-path <path>
```
